@@ -1,5 +1,5 @@
 import os
-from typing import Callable, Optional, Sequence, Tuple, Union
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import Tensor
@@ -14,10 +14,10 @@ class CommonVoiceDataset(Dataset):
         sub_version: int = 0,
         root: str = "./data",
         languages: Sequence[str] = ["en"],
-        with_sample_rate: bool = False,
+        with_info: bool = False,
         transforms: Optional[Callable] = None,
     ):
-        self.with_sample_rate = with_sample_rate
+        self.with_info = with_info
         self.transforms = transforms
 
         from datasets import interleave_datasets, load_dataset
@@ -37,15 +37,24 @@ class CommonVoiceDataset(Dataset):
 
     def __getitem__(
         self, idx: Union[Tensor, int]
-    ) -> Union[Tensor, Tuple[Tensor, Tensor]]:
+    ) -> Union[Tensor, Tuple[Tensor, Dict]]:
         idx = idx.tolist() if torch.is_tensor(idx) else idx  # type: ignore
         data = self.dataset[idx]
+
         waveform = torch.tensor(data["audio"]["array"]).view(1, -1)
-        sample_rate = data["audio"]["sampling_rate"]
+
+        info = dict(
+            sample_rate=data["audio"]["sampling_rate"],
+            text=data["sentence"],
+            age=data["age"],
+            accent=data["accent"],
+            gender=data["gender"],
+            locale=data["locale"],
+        )
 
         if self.transforms:
             waveform = self.transforms(waveform)
-        return (waveform, sample_rate) if self.with_sample_rate else waveform
+        return (waveform, info) if self.with_info else waveform
 
     def __len__(self) -> int:
         return len(self.dataset)
