@@ -1,7 +1,7 @@
 from .all import AllTransform
 from .crop import Crop
 from .loudness import Loudness
-from .overlap_channels import OverlapChannels
+from .mono import Mono
 from .randomcrop import RandomCrop
 from .resample import Resample
 from .scale import Scale
